@@ -33,7 +33,6 @@
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-scores.h>
 #include <libgames-support/games-scores-dialog.h>
-#include <libgames-support/games-sound.h>
 #include <libgames-support/games-stock.h>
 
 #ifdef WITH_SMCLIENT
@@ -108,14 +107,7 @@ static const GamesScoresCategory scorecats[] = {
   {"robots2_easy-super-safe", N_("Robots2 easy with super-safe moves")},
   {"robots_with_safe_teleport", N_("Robots with safe teleport")},
   {"robots_with_safe_teleport-safe", N_("Robots with safe teleport with safe moves")},
-  {"robots_with_safe_teleport-super-safe", N_("Robots with safe teleport with super-safe moves")},
-  GAMES_SCORES_LAST_CATEGORY
-};
-
-static const GamesScoresDescription scoredesc = { scorecats,
-  "classic_robots",
-  "gnobots2",
-  GAMES_SCORES_STYLE_PLAIN_DESCENDING
+  {"robots_with_safe_teleport-super-safe", N_("Robots with safe teleport with super-safe moves")}
 };
 
 /**********************************************************************/
@@ -214,19 +206,15 @@ main (int argc, char *argv[])
   EggSMClient *sm_client;
 #endif /* WITH_SMCLIENT */
 
-  g_thread_init (NULL);
-
   if (!games_runtime_init ("gnobots2"))
     return 1;
 
-  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
- 
   gettimeofday (&tv, NULL);
   srand (tv.tv_usec);
 
+#ifdef ENABLE_SETGID
   setgid_io_init ();
+#endif
 
   context = g_option_context_new (NULL);
 #if GLIB_CHECK_VERSION (2, 12, 0)
@@ -239,7 +227,6 @@ main (int argc, char *argv[])
 #endif /* WITH_SMCLIENT */
 
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
-  games_sound_add_option_group (context);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
   g_option_context_free (context);
@@ -251,7 +238,11 @@ main (int argc, char *argv[])
 
   g_set_application_name (_("Robots"));
 
-  highscores = games_scores_new (&scoredesc);
+  highscores = games_scores_new ("gnobots2",
+                                 scorecats, G_N_ELEMENTS (scorecats),
+                                 NULL, NULL,
+                                 0 /* default category */,
+                                 GAMES_SCORES_STYLE_PLAIN_DESCENDING);
 
   games_conf_initialise ("Gnobots2");
 
@@ -379,8 +370,6 @@ main (int argc, char *argv[])
     }
   }
 
-  update_score_state ();
-
   gtk_main ();
 
   games_conf_shutdown ();
