@@ -57,7 +57,6 @@
 #define KEY_BACKGROUND_COLOR  "background_color"
 #define KEY_CONFIGURATION     "configuration"
 #define KEY_ENABLE_SOUND      "enable_sound"
-#define KEY_ENABLE_SPLATS     "enable_splats"
 #define KEY_SAFE_MOVES        "use_safe_moves"
 #define KEY_SHOW_TOOLBAR      "show_toolbar"
 #define KEY_SUPER_SAFE_MOVES  "use_super_safe_moves"
@@ -78,7 +77,6 @@ struct _GnobotsProperties {
   gboolean safe_moves;
   gboolean super_safe_moves;
   gboolean sound;
-  gboolean splats;
   gboolean show_toolbar;
   GdkColor bgcolour;
   gint selected_config;
@@ -118,7 +116,6 @@ static void pmap_selection (GtkWidget *, gpointer);
 static void type_selection (GtkWidget *, gpointer);
 static void safe_cb (GtkWidget *, gpointer);
 static void sound_cb (GtkWidget *, gpointer);
-static void splat_cb (GtkWidget *, gpointer);
 static void defkey_cb (GtkWidget *, gpointer);
 static void fill_typemenu (GtkWidget *);
 static void conf_set_background_color (GdkColor * c);
@@ -277,22 +274,6 @@ sound_cb (GtkWidget * widget, gpointer data)
 }
 
 
-/**
- * splat_cb
- * @widget: widget
- * @data: callback data
- *
- * Description:
- * handles message from the 'splat' checkbox
- **/
-static void
-splat_cb (GtkWidget * widget, gpointer data)
-{
-  properties.splats = GTK_TOGGLE_BUTTON (widget)->active;
-  conf_set_enable_splats (properties.splats);
-}
-
-
 /**
  * defkey_cb
  * @widget: widget
@@ -457,7 +438,7 @@ show_properties_dialog (void)
   gtk_container_set_border_width (GTK_CONTAINER (cpage), 12);
 
   frame = games_frame_new (_("Game Type"));
-  gtk_box_pack_start (GTK_BOX (cpage), frame, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (cpage), frame, FALSE, FALSE, 0);
 
   vbox = gtk_vbox_new (FALSE, 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
@@ -476,17 +457,12 @@ show_properties_dialog (void)
   vbox = gtk_vbox_new (TRUE, 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-  table = gtk_table_new (2, 2, FALSE);
-  gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-  gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
-
   chkbox = gtk_check_button_new_with_mnemonic (_("_Use safe moves"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox),
 				properties.safe_moves);
   g_signal_connect (G_OBJECT (chkbox), "clicked",
 		    (GCallback) safe_cb, NULL);
-  gtk_table_attach (GTK_TABLE (table), chkbox, 0, 1, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), chkbox, TRUE, TRUE, 0);
   gtk_widget_set_tooltip_text (chkbox,
                                _("Prevent accidental moves that result in getting killed."));
 
@@ -495,27 +471,23 @@ show_properties_dialog (void)
 				properties.super_safe_moves);
   g_signal_connect (G_OBJECT (chkbox), "clicked",
 		    (GCallback) super_safe_cb, NULL);
-  gtk_table_attach (GTK_TABLE (table), chkbox, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), chkbox, TRUE, TRUE, 0);
   gtk_widget_set_tooltip_text (chkbox,
                                _("Prevents all moves that result in getting killed."));
 
+  frame = games_frame_new (_("Sound"));
+  gtk_box_pack_start (GTK_BOX (cpage), frame, FALSE, FALSE, 0);
+  vbox = gtk_vbox_new (TRUE, 6);
+  gtk_container_add (GTK_CONTAINER (frame), vbox);
+
   chkbox = gtk_check_button_new_with_mnemonic (_("_Enable sounds"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), properties.sound);
   g_signal_connect (G_OBJECT (chkbox), "clicked",
 		    (GCallback) sound_cb, NULL);
-  gtk_table_attach (GTK_TABLE (table), chkbox, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), chkbox, TRUE, TRUE, 0);
   gtk_widget_set_tooltip_text (chkbox,
                                _("Play sounds for events like winning a level and dying."));
 
-  chkbox = gtk_check_button_new_with_mnemonic (_("E_nable splats"));
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox),
-				properties.splats);
-  g_signal_connect (G_OBJECT (chkbox), "clicked", (GCallback) splat_cb,
-		    NULL);
-  gtk_table_attach (GTK_TABLE (table), chkbox, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
-  gtk_widget_set_tooltip_text (chkbox,
-                               _("Play the most common, and potentially the most annoying, sound."));
-
   label = gtk_label_new_with_mnemonic (_("Game"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), cpage, label);
 
@@ -652,8 +624,6 @@ load_properties (void)
 						        NULL);
   properties.sound = games_conf_get_boolean (KEY_PREFERENCES_GROUP,
                                              KEY_ENABLE_SOUND, NULL);
-  properties.splats = games_conf_get_boolean (KEY_PREFERENCES_GROUP,
-                                              KEY_ENABLE_SPLATS, NULL);
   properties.show_toolbar = games_conf_get_boolean (KEY_PREFERENCES_GROUP,
                                                     KEY_SHOW_TOOLBAR, NULL);
 
@@ -720,12 +690,6 @@ conf_set_enable_sound (gboolean value)
   games_conf_set_boolean (KEY_PREFERENCES_GROUP, KEY_ENABLE_SOUND, value);
 }
 
-void
-conf_set_enable_splats (gboolean value)
-{
-  games_conf_set_boolean (KEY_PREFERENCES_GROUP, KEY_ENABLE_SPLATS, value);
-}
-
 void
 conf_set_show_toolbar (gboolean value)
 {
@@ -763,7 +727,6 @@ save_properties (void)
   conf_set_use_safe_moves (properties.safe_moves);
   conf_set_use_super_safe_moves (properties.super_safe_moves);
   conf_set_enable_sound (properties.sound);
-  conf_set_enable_splats (properties.splats);
 
   return TRUE;
 }
@@ -817,22 +780,6 @@ properties_sound (void)
 }
 
 
-/**
- * properties_splats
- *
- * Description:
- * returns splat setting
- *
- * Returns:
- * TRUE if splats are selected
- **/
-gboolean
-properties_splats (void)
-{
-  return properties.splats;
-}
-
-
 /**
  * properties_show_toolbar
  *
