@@ -2,6 +2,7 @@
 /*
  * written by J. Marcin Gorycki <marcin.gorycki@intel.com>
  * massively altered for Clutter by Jason D. Clinton <me@jasonclinton.com>
+ * "bastard" mode by Lubomir Rintel <lkundrak@v3.sk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,88 +28,15 @@
 
 #define FONT "Sans Bold"
 
-GList *Block::destroy_blocks = NULL;
-ClutterBehaviour *Block::explode_fade_behaviour = NULL;
-ClutterTimeline *Block::move_time = NULL;
-ClutterTimeline *Block::explode_time = NULL;
-ClutterTimeline *Block::fall_time = NULL;
-
-void
-Block::move_end (ClutterTimeline *tml, gpointer *f)
-{
-	for (int x = 0; x < 4; ++x)
-		for (int y = 0; y < 4; ++y) {
-//			clutter_behaviour_remove_all (f->move_behaviour[x][y]);
-//			clutter_behaviour_path_clear ((ClutterBehaviourPath *) f->move_behaviour[x][y]);
-		}
-}
-
-void
-Block::explode_end (ClutterTimeline *tml, gpointer *data)
-{
-	Block *block;
-	g_list_foreach (destroy_blocks,
-			(GFunc)Block::reap_block,
-			block);
-	g_list_free (destroy_blocks);
-}
-
-void
-Block::fall_end (ClutterTimeline *tml, BlockOps *data)
-{
-	ClutterBehaviour *tmp_behave;
-//	if (fall_behaviours) {
-//		g_list_foreach (fall_behaviours,
-//				(GFunc)clutter_behaviour_remove_all,
-//				tmp_behave);
-//	}
-//	g_list_free (fall_behaviours);
-
-	//After fall, start the earthquake effect.
-	ClutterTimeline *tmp_timeline = clutter_timeline_new_for_duration
-						(120);
-	ClutterAlpha *tmp_alpha = clutter_alpha_new_full (tmp_timeline,
-					CLUTTER_EASE_OUT_ELASTIC);
-	ClutterPath *tmp_path = clutter_path_new ();
-	clutter_path_add_move_to (tmp_path, data->center_anchor_x,
-				 data->center_anchor_y);
-	clutter_path_add_move_to (tmp_path, data->center_anchor_x,
-				 data->center_anchor_y + data->cell_height *
-				 data->quake_ratio);
-	tmp_behave = clutter_behaviour_path_new (tmp_alpha, tmp_path);
-	clutter_behaviour_apply (tmp_behave, CLUTTER_ACTOR (data->playingField));
-	g_object_unref (tmp_timeline);
-	g_object_unref (tmp_alpha);
-}
-
-/* fuck C++ */
-void
-Block::reap_block (Block *block)
-{
-	delete block;
-}
-
 Block::Block ():
 	what(EMPTY),
 	actor(NULL),
 	x(0),
 	y(0),
 	move_behaviour(NULL),
-	explode_move_behaviour(NULL),
-	fall_behaviour(NULL)
-{
-	if (!move_time)
-		move_time = clutter_timeline_new_for_duration (60);
-	if (!explode_time)
-		explode_time = clutter_timeline_new_for_duration (120);
-	if (!fall_time)
-		fall_time = clutter_timeline_new_for_duration (120);
-	ClutterAlpha *move_alpha = clutter_alpha_new_full (move_time,
-							   CLUTTER_EASE_OUT_QUAD);
-	move_behaviour = clutter_behaviour_path_new_with_knots (move_alpha,
-								NULL, NULL);
-	g_object_unref (move_alpha);
-}
+	fall_behaviour(NULL),
+	explode_move_behaviour(NULL)
+{}
 
 Block::~Block ()
 {
@@ -116,40 +44,58 @@ Block::~Block ()
 		clutter_actor_destroy (CLUTTER_ACTOR(actor));
 	if (move_behaviour)
 		g_object_unref (move_behaviour);
+	if (fall_behaviour)
+		g_object_unref (fall_behaviour);
+	if (explode_move_behaviour)
+		g_object_unref (explode_move_behaviour);
 }
 
 void
-Block::createActor (ClutterActor *chamber, ClutterActor *texture_source)
+Block::createActor (ClutterActor *chamber, cairo_surface_t *texture_source)
 {
 	if (actor)
 		clutter_actor_destroy (CLUTTER_ACTOR(actor));
-	actor = clutter_clone_new (CLUTTER_ACTOR(texture_source));
+	actor = clutter_texture_new ();
+	// FIXME jclinton ... this should really be cluttercairo somehow for efficiency
+	clutter_texture_set_from_rgb_data (CLUTTER_TEXTURE(actor),
+					   cairo_image_surface_get_data(texture_source),
+					   TRUE,
+					   cairo_image_surface_get_width(texture_source),
+					   cairo_image_surface_get_height(texture_source),
+					   cairo_image_surface_get_stride(texture_source),
+					   32, CLUTTER_TEXTURE_NONE, NULL);
 	clutter_group_add (CLUTTER_GROUP (chamber), actor);
 	clutter_actor_set_position (CLUTTER_ACTOR(actor), x, y);
 	clutter_actor_show (CLUTTER_ACTOR(actor));
 }
 
+void
+Block::bindAnimations (BlockOps *f)
+{
+	move_behaviour = clutter_behaviour_path_new_with_knots (f->move_alpha,
+								NULL, 0);
+
+	fall_behaviour = clutter_behaviour_path_new_with_knots (f->fall_alpha,
+								NULL, 0);
+
+	explode_move_behaviour = clutter_behaviour_path_new_with_knots (f->explode_alpha,
+									NULL, 0);
+}
+
 Block&
-Block::move_from (Block& b, BlockOps *f)
+Block::moveFrom (Block& b, BlockOps *f)
 {
 	if (this != &b) {
 		what = b.what;
 		b.what = EMPTY;
 		color = b.color;
 		b.color = 0;
-		if (actor) {
-			//this shouldn't happen
-			destroy_blocks = g_list_prepend (destroy_blocks, actor);
-		}
 		if (b.actor) {
 			const ClutterKnot knot_line[] = {{b.x, b.y}, {x, y}};
-			ClutterAlpha *fall_alpha = clutter_alpha_new_full
-							(fall_time,
-							 CLUTTER_EASE_IN_QUAD);
-			fall_behaviour = clutter_behaviour_path_new_with_knots
-				(fall_alpha, knot_line, 2);
+			fall_behaviour = clutter_behaviour_path_new_with_knots (f->fall_alpha,
+										knot_line, 2);
 			clutter_behaviour_apply (fall_behaviour, b.actor);
-			g_object_unref (fall_alpha);
+			f->fall_behaviours = g_list_prepend (f->fall_behaviours, fall_behaviour);
 		}
 		actor = b.actor;
 		b.actor = NULL;
@@ -157,7 +103,52 @@ Block::move_from (Block& b, BlockOps *f)
 	return *this;
 }
 
+/******************************************************************************/
+
+gboolean
+BlockOps::move_end (ClutterTimeline *time, BlockOps *f)
+{
+	return FALSE;
+}
+
+gboolean
+BlockOps::explode_end (ClutterTimeline *time, BlockOps *f)
+{
+	Block *block = NULL;
+	g_list_foreach (f->destroy_actors,
+			(GFunc)clutter_actor_destroy,
+			block);
+	g_list_free (f->destroy_actors);
+	f->destroy_actors = NULL;
+	return FALSE;
+}
+
+gboolean
+BlockOps::fall_end (ClutterTimeline *tml, BlockOps *f)
+{
+	Block *behave = NULL;
+	g_list_foreach (f->fall_behaviours,
+			(GFunc)clutter_behaviour_remove_all,
+			behave);
+	g_list_free (f->fall_behaviours);
+	f->fall_behaviours = NULL;
+
+	//After fall, start the earthquake effect
+	ClutterPath *path_line = clutter_path_new ();
+	clutter_path_add_move_to (path_line,
+				  f->center_anchor_x,
+				  f->center_anchor_y + f->cell_height * f->quake_ratio);
+	clutter_path_add_line_to (path_line, f->center_anchor_x, f->center_anchor_y);
+	clutter_behaviour_remove_all (f->quake_behaviour);
+	clutter_behaviour_path_set_path (CLUTTER_BEHAVIOUR_PATH(f->quake_behaviour), path_line);
+	clutter_behaviour_apply (f->quake_behaviour, f->playingField);
+	clutter_timeline_start (f->quake_time);
+	return FALSE;
+}
+
 BlockOps::BlockOps() :
+	destroy_actors(NULL),
+	fall_behaviours(NULL),
 	quake_ratio(0.0),
 	background(NULL),
 	foreground(NULL),
@@ -170,15 +161,13 @@ BlockOps::BlockOps() :
 	blocknr(0),
 	rot(0),
 	color(0),
+	animate(true),
 	backgroundImage(NULL),
 	center_anchor_x(0),
-	center_anchor_y(0)
+	center_anchor_y(0),
+	FALL_TIMING(360),
+	QUAKE_TIMING(720)
 {
-	field = new Block*[COLUMNS];
-
-	for (int i = 0; i < COLUMNS; ++i)
-		field[i] = new Block[LINES];
-
 	w = gtk_clutter_embed_new ();
 
 	g_signal_connect (w, "size_allocate", G_CALLBACK (resize), this);
@@ -190,6 +179,47 @@ BlockOps::BlockOps() :
 
 	playingField = clutter_group_new ();
 	clutter_group_add (CLUTTER_GROUP(stage), CLUTTER_ACTOR(playingField));
+	
+	move_time = clutter_timeline_new (60);
+	g_signal_connect (move_time, "completed", G_CALLBACK
+			  (BlockOps::move_end), this);
+	move_alpha = clutter_alpha_new_full (move_time,
+					     CLUTTER_EASE_IN_QUAD);
+
+	fall_time = clutter_timeline_new (FALL_TIMING);
+	g_signal_connect (fall_time, "completed", G_CALLBACK
+			  (BlockOps::fall_end), this);
+	fall_alpha = clutter_alpha_new_full (fall_time,
+					     CLUTTER_EASE_IN_QUAD);
+
+	explode_time = clutter_timeline_new (720);
+	g_signal_connect (explode_time, "completed", G_CALLBACK
+			  (BlockOps::explode_end), this);
+	explode_alpha = clutter_alpha_new_full (explode_time,
+						CLUTTER_EASE_OUT_QUINT);
+	explode_fade_behaviour = clutter_behaviour_opacity_new (explode_alpha,
+								255, 0);
+	explode_scale_behaviour = clutter_behaviour_scale_new (explode_alpha,
+								1.0, 1.0,
+								2.0, 2.0);
+
+	quake_time = clutter_timeline_new (QUAKE_TIMING);
+	quake_alpha = clutter_alpha_new_full (quake_time,
+					      CLUTTER_EASE_OUT_BOUNCE);
+	quake_behaviour = clutter_behaviour_path_new_with_knots (quake_alpha,
+								 NULL, 0);
+
+	field = new Block*[COLUMNS];
+	backfield = new Block*[COLUMNS];
+	for (int i = 0; i < COLUMNS; ++i)
+	{
+		field[i] = new Block[LINES];
+		backfield[i] = new Block[LINES];
+		for (int j = 0; j < LINES; ++j)
+		{
+			field[i][j].bindAnimations (this);
+		}
+	}
 }
 
 BlockOps::~BlockOps()
@@ -198,6 +228,14 @@ BlockOps::~BlockOps()
 		delete[] field[i];
 
 	delete[] field;
+	
+	g_object_unref (move_time);
+	g_object_unref (fall_time);
+	g_object_unref (explode_time);
+	g_object_unref (explode_fade_behaviour);
+	g_object_unref (explode_scale_behaviour);
+	g_object_unref (quake_time);
+	g_object_unref (quake_behaviour);
 }
 
 bool
@@ -257,7 +295,7 @@ BlockOps::moveBlockLeft()
 	if (blockOkHere(posx - 1, posy, blocknr, rot))
 	{
 		--posx;
-		updateBlockInField();
+		moveBlockInField(-1, 0);
 		moved = true;
 	}
 
@@ -272,7 +310,7 @@ BlockOps::moveBlockRight()
 	if (blockOkHere(posx + 1, posy, blocknr, rot))
 	{
 		++posx;
-		updateBlockInField();
+		moveBlockInField(1, 0);
 		moved = true;
 	}
 
@@ -317,7 +355,7 @@ BlockOps::moveBlockDown()
 	if (!fallen)
 	{
 		++posy;
-		updateBlockInField();
+		moveBlockInField(0, 1);
 	}
 
 	return fallen;
@@ -340,7 +378,15 @@ BlockOps::fallingToLaying()
 	for (int x = 0; x < COLUMNS; ++x)
 		for (int y = 0; y < LINES; ++y)
 			if (field[x][y].what == FALLING)
+			{
 				field[x][y].what = LAYING;
+				if (!animate)
+					continue;
+				clutter_actor_set_position (field[x][y].actor,
+							    field[x][y].x,
+							    field[x][y].y);
+				clutter_behaviour_remove_all (field[x][y].move_behaviour);
+			}
 }
 
 void
@@ -352,15 +398,19 @@ BlockOps::eliminateLine(int l)
 			int cur_x, cur_y = 0;
 			g_object_get (G_OBJECT (field[x][l].actor), "x", &cur_x, "y", &cur_y, NULL);
 			clutter_actor_raise_top (field[x][l].actor);
-//			clutter_effect_fade (Block::explode_tmpl, field[x][l].actor, 0, NULL, NULL);
-//			clutter_effect_move (Block::explode_tmpl, field[x][l].actor,
-//					cur_x + g_random_int_range(-60 - cell_width / 4, 60),
-//					cur_y + g_random_int_range(-60 - cell_height / 4, 60),
-//					NULL, NULL);
-//			clutter_effect_scale (Block::explode_tmpl, field[x][l].actor,
-//					1.5, 1.5, NULL, NULL);
-			Block::destroy_blocks = g_list_append (Block::destroy_blocks,
-							       &field[x][l]);
+			ClutterPath *path_line = clutter_path_new ();
+			clutter_path_add_move_to (path_line, cur_x, cur_y);
+			clutter_path_add_line_to (path_line,
+						  cur_x + g_random_int_range (-60 - cell_width / 4, 60),
+						  cur_y + g_random_int_range (-60 - cell_height / 4, 60));
+			clutter_behaviour_remove_all (field[x][l].explode_move_behaviour);
+			clutter_behaviour_path_set_path (CLUTTER_BEHAVIOUR_PATH(field[x][l].explode_move_behaviour),
+							 path_line);
+			clutter_behaviour_apply (field[x][l].explode_move_behaviour, field[x][l].actor);
+			clutter_behaviour_apply (explode_fade_behaviour, field[x][l].actor);
+			clutter_behaviour_apply (explode_scale_behaviour, field[x][l].actor);
+			destroy_actors = g_list_prepend (destroy_actors, field[x][l].actor);
+			field[x][l].actor = NULL;
 		}
 	}
 }
@@ -385,57 +435,173 @@ int
 BlockOps::checkFullLines()
 {
 	// we can have at most 4 full lines (vertical block)
-	int numFullLines = 0;
-	int numCascades = 0;
+	int num_full_lines = 0;
+	clutter_behaviour_remove_all (explode_fade_behaviour);
+	clutter_behaviour_remove_all (explode_scale_behaviour);
 
 	for (int y = MIN (posy + 4, LINES); y > 0; --y)
 	{
 		if (checkFullLine (y))
 		{
-			++numFullLines;
+			++num_full_lines;
 			eliminateLine(y);
 		}
-		else if (numFullLines > 0)
+		else if (num_full_lines > 0)
 		{
 			for (int x = 0; x < COLUMNS; ++x)
 			{
-				field[x][y+numFullLines].move_from (field[x][y], this);
+				field[x][y + num_full_lines].moveFrom (field[x][y], this);
 			}
-			++numCascades;
 		}
 	}
 
-	if (numFullLines > 0)
+	if (num_full_lines > 0)
 	{
-//		g_signal_connect (Block::fall_time, "completed",
-//				G_CALLBACK (Block::fall_end), this);
-//		g_signal_connect (Block::explode_tml, "completed",
-//				  G_CALLBACK (Block::explode_end), (gpointer) NULL);
-		clutter_timeline_start (Block::fall_time);
-		clutter_timeline_start (Block::explode_time);
-		quake_ratio = ((float) numCascades) / (float) LINES;
+		clutter_timeline_set_duration (fall_time, FALL_TIMING / (5 - num_full_lines));
+		clutter_timeline_set_duration (quake_time, QUAKE_TIMING / (5 - num_full_lines));
+		clutter_timeline_start (fall_time);
+		clutter_timeline_start (explode_time);
+		quake_ratio = ((float) num_full_lines) / 4.0;
 	}
 
-	return numFullLines;
+	return num_full_lines;
+}
+
+void
+BlockOps::saveField ()
+{
+	for (int y = 0; y < LINES; y++)
+		for (int x = 0; x < COLUMNS; x++)
+			backfield[x][y] = field[x][y];
+}
+
+void
+BlockOps::restoreField ()
+{
+	for (int y = 0; y < LINES; y++)
+		for (int x = 0; x < COLUMNS; x++)
+			field[x][y] = backfield[x][y];
+}
+
+/*
+ * An implementation of "Bastard" algorithm 
+ * it comes from Federico Poloni's "bastet"
+ */
+
+void
+BlockOps::bastardPick ()
+{
+	int scores[tableSize];
+	int blocks[tableSize];
+	int chance[tableSize];
+
+	animate = false;
+	/* This generates a priority for each block */
+	saveField ();
+	for (blocknr = 0; blocknr < tableSize; blocknr++)
+	{
+		scores[blocknr] = -32000;
+		for (rot = 0; rot < 4; rot++)
+		{
+			for (posx = 0; posx < COLUMNS; posx++)
+			{
+				int this_score = 0;
+				int x, y;
+
+				if (!blockOkHere(posx, posy = 0, blocknr, rot))
+					continue;
+
+				dropBlock();
+				fallingToLaying();
+
+				/* Count the completed lines */
+				for (y = MIN (posy + 4, LINES); y > 0; --y) {
+					if (checkFullLine(y)) {
+						this_score += 5000;
+					}
+				}
+
+				/* Count heights of columns */
+				for (x = 0; x < COLUMNS; x++)
+				{
+					for (y = 0; y < LINES; y++)
+						if (field[x][y].what == LAYING)
+							break;
+					this_score -= 5 * (LINES - y);
+				}
+
+				restoreField ();
+				if (scores[blocknr] < this_score)
+					scores[blocknr] = this_score;
+			}
+		}
+	}
+
+	for (int i = 0; i < tableSize; i++) {
+		/* Initialize chances table */
+		chance[i] = 100;
+		/* Initialize block/priority table */
+		blocks[i] = i;
+		/* Perturb score (-2 to +2), to avoid stupid tie handling */
+		scores[i] += g_random_int_range(-2, 2);
+	}
+
+	/* Sorts blocks by priorities, worst (interesting to us) first*/
+	for (int i = 0; i < tableSize; i++)
+	{
+		for (int ii = 0; ii < tableSize - 1; ii++)
+		{
+			if (scores[blocks[ii]] > scores[blocks[ii+1]])
+			{
+				int t = blocks[ii];
+				blocks[ii] = blocks[ii+1];
+				blocks[ii+1] = t;
+			}
+		}
+	}
+
+	/* Lower the chances we're giving the worst one */
+	chance[0] = 75;
+	chance[1] = 92;
+	chance[2] = 98;
+
+	/* Actually choose a piece */
+	int rnd = g_random_int_range(0, 99);
+	for (int i = 0; i < tableSize; i++)
+	{
+		blocknr = blocks[i];
+		if (rnd < chance[i])
+			break;
+	}
+
+	/* This will almost certainly not given next */
+	blocknr_next = blocks[tableSize-1];
+	animate = true;
 }
 
 bool
 BlockOps::generateFallingBlock()
 {
+	if (bastard_mode)
+	{
+		bastardPick();
+		color_next = -1;
+	}
+	else
+	{
+		blocknr = blocknr_next == -1 ? g_random_int_range(0, tableSize) :
+			blocknr_next;
+		blocknr_next = g_random_int_range(0, tableSize);
+	}
+
 	posx = COLUMNS / 2 + 1;
 	posy = 0;
 
-	posx_old = COLUMNS / 2 + 1;
-	posy_old = 0;
-
-	blocknr = blocknr_next == -1 ? g_random_int_range(0, tableSize) :
-		blocknr_next;
 	rot = rot_next == -1 ? g_random_int_range(0, 4) : rot_next;
 	int cn = random_block_colors ? g_random_int_range(0, NCOLOURS) :
 		blocknr % NCOLOURS;
 	color = color_next == -1 ? cn : color_next;
 
-	blocknr_next = g_random_int_range(0, tableSize);
 	rot_next = g_random_int_range(0, 4);
 	color_next = random_block_colors ? g_random_int_range(0, NCOLOURS) :
 		blocknr_next % NCOLOURS;
@@ -498,9 +664,8 @@ BlockOps::putBlockInField (SlotType fill)
 					field[i][j].createActor (playingField,
 								 renderer->getCacheCellById (color));
 				} else {
-					//FIXME jclinton these seem redundant
 					if (field[i][j].actor) {
-						clutter_actor_destroy (CLUTTER_ACTOR(field[i][j].actor));
+						clutter_actor_destroy (field[i][j].actor);
 						field[i][j].actor = NULL;
 					}
 				}
@@ -510,13 +675,8 @@ BlockOps::putBlockInField (SlotType fill)
 }
 
 void
-BlockOps::updateBlockInField ()
+BlockOps::moveBlockInField (gint x_trans, gint y_trans)
 {
-	int shift_x = posx - posx_old;
-	int shift_y = posy - posy_old;
-	if (shift_x == 0 && shift_y == 0)
-		return;
-
 	ClutterActor *blocks_actor[4][4] = {{0, }};
 
 	for (int x = 0; x < 4; ++x) {
@@ -525,37 +685,38 @@ BlockOps::updateBlockInField ()
 				int i = posx - 2 + x;
 				int j = y + posy;
 
-				blocks_actor[x][y] = field[i-shift_x][j-shift_y].actor;
-				field[i-shift_x][j-shift_y].what = EMPTY;
-				field[i-shift_x][j-shift_y].color = 0;
-				field[i-shift_x][j-shift_y].actor = NULL;
+				blocks_actor[x][y] = field[i-x_trans][j-y_trans].actor;
+				field[i-x_trans][j-y_trans].what = EMPTY;
+				field[i-x_trans][j-y_trans].actor = NULL;
+				if (animate)
+					clutter_behaviour_remove_all (field[i-x_trans][j-y_trans].move_behaviour);
 			}
 		}
 	}
 	for (int x = 0; x < 4; ++x) {
 		for (int y = 0; y < 4; ++y) {
 			if (blockTable[blocknr][rot][x][y]) {
-				int i = posx - 2 + x;
-				int j = y + posy;
+				gint i = posx - 2 + x;
+				gint j = y + posy;
 
 				field[i][j].what = FALLING;
 				field[i][j].color = color;
 				field[i][j].actor = blocks_actor[x][y];
-				if (field[i][j].actor) {
-					int cur_x, cur_y = 0;
+				if (field[i][j].actor && animate) {
+					gint cur_x, cur_y = 0;
 					g_object_get (G_OBJECT (field[i][j].actor), "x", &cur_x, "y", &cur_y, NULL);
-					const ClutterKnot knot_line[] = {{cur_x, cur_y}, {field[i][j].x, field[i][j].y}};
-//					clutter_behaviour_remove_all (move_path[x][y]);
-//					clutter_behaviour_path_clear ((ClutterBehaviourPath *) move_path[x][y]);
-//					clutter_behaviour_path_append_knots ((ClutterBehaviourPath *) move_path[x][y], &knot_line[0], &knot_line[1], NULL);
-//					clutter_behaviour_apply (move_path[x][y], field[i][j].actor);
+					ClutterPath *path_line = clutter_path_new ();
+					clutter_path_add_move_to (path_line, cur_x, cur_y);
+					clutter_path_add_line_to (path_line, field[i][j].x, field[i][j].y);
+					clutter_behaviour_remove_all (field[i][j].move_behaviour);
+					clutter_behaviour_path_set_path (CLUTTER_BEHAVIOUR_PATH(field[i][j].move_behaviour), path_line);
+					clutter_behaviour_apply (field[i][j].move_behaviour, field[i][j].actor);
 				}
 			}
 		}
 	}
-	clutter_timeline_start (Block::move_time);
-	posx_old = posx;
-	posy_old = posy;
+	if (animate)
+		clutter_timeline_start (move_time);
 }
 
 bool
@@ -615,9 +776,9 @@ BlockOps::rescaleField ()
 	}
 
 	if (background) {
-//		clutter_actor_set_size (CLUTTER_ACTOR(background), width, height);
-//		clutter_cairo_texture_set_size (CLUTTER_CAIRO_TEXTURE(background),
-//					      width, height);
+		clutter_actor_set_size (CLUTTER_ACTOR(background), width, height);
+		clutter_cairo_texture_set_surface_size (CLUTTER_CAIRO_TEXTURE(background),
+							width, height);
 	} else {
 		background = clutter_cairo_texture_new (width, height);
 		/*FIXME jclinton: eventually allow solid color background
@@ -634,8 +795,8 @@ BlockOps::rescaleField ()
 	if (foreground) {
 		clutter_actor_set_size (CLUTTER_ACTOR(foreground),
 					width, height);
-//		clutter_cairo_surface_resize (CLUTTER_CAIRO(foreground),
-//					      width, height);
+		clutter_cairo_texture_set_surface_size (CLUTTER_CAIRO_TEXTURE(foreground),
+							width, height);
 	} else {
 		foreground = clutter_cairo_texture_new (width, height);
 		clutter_group_add (CLUTTER_GROUP (stage),
